@@ -1,8 +1,11 @@
 package server
 
 import (
+	"compress/gzip"
 	"fmt"
+	"io"
 	"net/http"
+	"strings"
 
 	"github.com/openshift/console/auth"
 )
@@ -55,6 +58,37 @@ func authMiddlewareWithUser(a *auth.Authenticator, handlerFunc func(user *auth.U
 	})
 }
 
+type gzipResponseWriter struct {
+	io.Writer
+	http.ResponseWriter
+	sniffDone bool
+}
+
+func (w *gzipResponseWriter) Write(b []byte) (int, error) {
+	if !w.sniffDone {
+		if w.Header().Get("Content-Type") == "" {
+			w.Header().Set("Content-Type", http.DetectContentType(b))
+		}
+		w.sniffDone = true
+	}
+	return w.Writer.Write(b)
+}
+
+// gzipHandler wraps a http.Handler to support transparent gzip encoding.
+func gzipHandler(h http.Handler) http.Handler {
+	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		w.Header().Add("Vary", "Accept-Encoding")
+		if !strings.Contains(r.Header.Get("Accept-Encoding"), "gzip") {
+			h.ServeHTTP(w, r)
+			return
+		}
+		w.Header().Set("Content-Encoding", "gzip")
+		gz := gzip.NewWriter(w)
+		defer gz.Close()
+		h.ServeHTTP(&gzipResponseWriter{Writer: gz, ResponseWriter: w}, r)
+	})
+}
+
 func securityHeadersMiddleware(hdlr http.Handler) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		// Prevent MIME sniffing (https://en.wikipedia.org/wiki/Content_sniffing)
